module.exports = defineTest({
	description: 'supports destructuring declarations for systemJS',
	options: {
		output: {
			format: 'system'
		}
	}
});
